/*
 * This file is a part of Winix
 * and is not publicly distributed
 * 
 * Copyright (c) 2012, Tomasz Sowa
 * All rights reserved.
 * 
 */
 
#include "pw.h"
#include "core/log.h"
#include "core/misc.h"


namespace Fun
{

Pw::Pw()
{
	fun.url = L"pw";
}


bool Pw::HasAccess()
{
	return true;
}



bool Pw::ActivateAccount(User * puser, long code, bool use_ses_log)
{
	std::wstring * user_code_str = puser->aenv.GetValue(L"activation_code");

	if( user_code_str )
	{
		if( Tol(*user_code_str) == code )
		{
			if( db->ChangeUserStatus(puser->id, WINIX_ACCOUNT_READY) == WINIX_ERR_OK )
			{
				// !! IMPROVE ME
				// remove 'activation_code' value from admin environment for the user
				puser->status = WINIX_ACCOUNT_READY;
				log << log2 << "Pw: account: " << puser->name << " activated" << logend;

				if( use_ses_log )
					slog << loginfo << T(L"account_activated") << logend;

				return true;
			}
			else
			{
				log << log1 << "Pw: account not activated -- database error" << logend;
			}
		}
		else
		{
			log << log2 << "Pw: incorrect activation code" << logend;

			if( use_ses_log )
				slog << logerror << T(L"incorrect_activation_code") << logend;
		}
	}
	else
	{
		log << log1 << "Pw: there is no activation_code value in admin environment" << logend;

		if( use_ses_log )
			slog << loginfo << T(L"account_cannot_be_activated") << logend;
	}

return false;
}


bool Pw::ActivateAccount(const std::wstring & login, long code, bool use_ses_log)
{
	bool result  = false;
	User * puser = system->users.GetUser(login);

	if( puser )
	{
		if( puser->status == WINIX_ACCOUNT_NOT_ACTIVATED )
		{
			result = ActivateAccount(puser, code, use_ses_log);
		}
		else
		{
			log << log2 << "Pw: this account is already activated" << logend;

			if( use_ses_log )
				slog << loginfo << T(L"account_already_activated") << logend;
		}
	}
	else
	{
		log << log1 << "Pw: there is no a user: " << login << logend;
	}

return result;
}



void Pw::ActivateAccount()
{
	const std::wstring & login = cur->request->ParamValue(L"login");
	long code = Tol(cur->request->ParamValue(L"code"));

	if( ActivateAccount(login, code, true) )
		system->RedirectToLastItem();
}



void Pw::MakeGet()
{
	if( cur->request->IsParam(L"activate") )
		ActivateAccount();
}




} // namespace

